import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// percent
const numberFormat = number =>
  	(Math.abs(Number(number))) + " %" ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.inflation_rate)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  
  

// put spacing between the slices
const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(160)
  .padAngle(0.01)
  .cornerRadius(4);

// create sections of pie chart
const sections = svg.append("g")
  .attr("transform", `translate(230,220)`)
  .selectAll("path")
  .data(pieData);
  
sections.enter()
  .append("path")
  .attr("d", arcGenerator)
  .attr("fill", d => colors(d.data.inflation_rate))
  .on("mouseover", d => console.log(d.data.inflation_rate));
  
// add legend to the pie chart
const legends = svg.append("g")
  .attr("transform", "translate(500,60)")
  .selectAll(".legends")
  .data(pieData);
  
const legend = legends.enter()
  .append("g")
  .classed(".legends",true)
  .attr("transform", (d,i)=>{
    return `translate(0,${(i+1)*30})`;
  });



  
  // list each country as label 

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.inflation_rate));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.inflation_rate));
}

// url of data on Gist

const csvUrl =
 'https://gist.githubusercontent.com/kevinraj127/42707c203bd4ba0a1f2ec347c1fae023/raw/e512a2d1751a0c2854cce0b4a3db416487e14c3f/inflation_rates_g20_feb_2023.csv'

//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => 
    csvData.sort((data1, data2) => data2.inflation_rate-data1.inflation_rate);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});
